==> haskell-wai-cors-0.2.5-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.5
id: wai-cors-0.2.5-CYkHD1joIUB3DJtsbfKDWK
key: wai-cors-0.2.5-CYkHD1joIUB3DJtsbfKDWK
license: MIT
copyright: (c) 2015-2016 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
abi: 47ff99fd6f5d101939ce75e68efe99ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-cors-0.2.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-cors-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/wai-cors-0.2.5
hs-libraries: HSwai-cors-0.2.5-CYkHD1joIUB3DJtsbfKDWK
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    base-unicode-symbols-0.2.2.4-LJZ89aUbdoNKMBk8U5mv47
    bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.5-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.5
id: wai-cors-0.2.5-4ZiyE8G3XevD9zvtU7yEAF
key: wai-cors-0.2.5-4ZiyE8G3XevD9zvtU7yEAF
license: MIT
copyright: (c) 2015-2016 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
abi: 90f9174c35511e7b9cc23132966b0396
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-cors-0.2.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-cors-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/wai-cors-0.2.5
hs-libraries: HSwai-cors-0.2.5-4ZiyE8G3XevD9zvtU7yEAF
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    base-unicode-symbols-0.2.2.4-LJZ89aUbdoNKMBk8U5mv47
    bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
